package Hydraulic
  model DvaBalonky
    Real p1, p2;
    Real q1, q2;
    parameter Real R = 1;
    parameter Real E1 = 0.3;
    parameter Real E2 = 1;
    Real V1(start = 200), V2(start = 100);
  equation
    (p1 - p2) / R = -q1;
    //+/-
    q2 = -q1;
    V1 * E1 = p1;
    q1 = der(V1);
    V2 * E2 = p2;
    q2 = der(V2);
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
  end DvaBalonky;

  model Balon
    Real V;
    parameter Real E = 1;
    Real p, q;
  equation
    V * E = p;
    der(V) = q;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
  end Balon;

  model Odpor
    parameter Real R = 1;
    Real p1, p2;
    Real q1, q2;
  equation
    (p1 - p2) / R = q1;
    //+/-
    q1 + q2 = 0;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
  end Odpor;

  model DvaBalonkyObjektove
    Balon b1(V.start = 200), b2(V.start = 100);
    Odpor odpor;
  equation
    b1.p = odpor.p1;
    b2.p = odpor.p2;
    b1.q + odpor.q1 = 0;
    // b1.q = -odpor.q1;
    b2.q + odpor.q2 = 0;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
  end DvaBalonkyObjektove;

  connector Spunt
    Real p;
    flow Real q;
    annotation(Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Ellipse(origin = {6.32, -6.09}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Sphere, extent = {{-85.48, 87.59}, {85.48, -87.59}}, endAngle = 360)}));
  end Spunt;

  model BalonSSpuntem
    Hydraulic.Spunt spunt1 annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {20, 0}, extent = {{-35, -35}, {35, 35}}, rotation = 0)));
    parameter Real E = 1;
    Real V;
  equation
    V * E = spunt1.p;
    der(V) = spunt1.q;
    annotation(Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Ellipse(origin = {14.05, -7.03}, lineThickness = 1, extent = {{-82.44, 86.18}, {82.44, -86.18}}, endAngle = 360), Line(origin = {29.9986, -50.0593}, points = {{-56.6965, -16.9196}, {-17.8206, -32.3763}, {8.87729, -32.3763}, {29.4862, -14.5777}, {29.4862, -14.5777}}), Line(origin = {23.3007, 65.0227}, points = {{-56.6965, -16.9196}, {-18.289, 3.22088}, {7.00376, 1.34734}, {29.4862, -14.5777}, {29.4862, -14.5777}})}));
  end BalonSSpuntem;

  model OdporSSpunty
    Hydraulic.Spunt spunt2 annotation(Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-25, -25}, {25, 25}}, rotation = 0)));
    Hydraulic.Spunt spunt1 annotation(Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-25, -25}, {25, 25}}, rotation = 0)));
    parameter Real R = 1;
  equation
    (spunt1.p - spunt2.p) / R = spunt1.q;
    spunt1.q + spunt2.q = 0;
    annotation(Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Rectangle(origin = {1.87354, -6.55738}, extent = {{-91.3349, 33.7237}, {91.3349, -33.7237}})}));
  end OdporSSpunty;

  model DvaBalonkyAkauzalne
    Hydraulic.BalonSSpuntem balonsspuntem1(V(start = 200)) annotation(Placement(visible = true, transformation(origin = {-60, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Hydraulic.OdporSSpunty odporsspunty1 annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Hydraulic.BalonSSpuntem balonsspuntem2(V(start = 100)) annotation(Placement(visible = true, transformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(odporsspunty1.spunt1, balonsspuntem1.spunt1) annotation(Line(points = {{-10, 0}, {-57.6112, 0}, {-57.6112, -1.40515}, {-57.6112, -1.40515}}));
    connect(balonsspuntem2.spunt1, odporsspunty1.spunt2) annotation(Line(points = {{82, 0}, {10.3044, 0}, {10.3044, -1.87354}, {10.3044, -1.87354}}));
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
  end DvaBalonkyAkauzalne;
  annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
end Hydraulic;